======
String
======

The following methods are available under the `Series.str` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    Series.str.concat
    Series.str.contains
    Series.str.count_match
    Series.str.decode
    Series.str.encode
    Series.str.ends_with
    Series.str.explode
    Series.str.extract
    Series.str.extract_all
    Series.str.extract_groups
    Series.str.json_extract
    Series.str.json_path_match
    Series.str.lengths
    Series.str.ljust
    Series.str.lstrip
    Series.str.n_chars
    Series.str.replace
    Series.str.replace_all
    Series.str.rjust
    Series.str.rstrip
    Series.str.slice
    Series.str.split
    Series.str.split_exact
    Series.str.splitn
    Series.str.starts_with
    Series.str.strip
    Series.str.strptime
    Series.str.to_date
    Series.str.to_datetime
    Series.str.to_decimal
    Series.str.to_lowercase
    Series.str.to_time
    Series.str.to_titlecase
    Series.str.to_uppercase
    Series.str.zfill
    Series.str.parse_int
